Enum parquet::basic::Type [−][src]
pub enum Type {
BOOLEAN,
INT32,
INT64,
INT96,
FLOAT,
DOUBLE,
BYTE_ARRAY,
FIXED_LEN_BYTE_ARRAY,
}Types supported by Parquet. These physical types are intended to be used in combination with the encodings to control the on disk storage format. For example INT16 is not included as a type since a good encoding of INT32 would handle this.
Variants
BOOLEANINT32INT64INT96FLOATDOUBLEBYTE_ARRAYFIXED_LEN_BYTE_ARRAY