Enum parquet::basic::Encoding [−][src]
pub enum Encoding {
PLAIN,
PLAIN_DICTIONARY,
RLE,
BIT_PACKED,
DELTA_BINARY_PACKED,
DELTA_LENGTH_BYTE_ARRAY,
DELTA_BYTE_ARRAY,
RLE_DICTIONARY,
}Encodings supported by Parquet. Not all encodings are valid for all types. These enums are also used to specify the encoding of definition and repetition levels.
Variants
PLAINDefault byte encoding.
- BOOLEAN - 1 bit per value, 0 is false; 1 is true.
- INT32 - 4 bytes per value, stored as little-endian.
- INT64 - 8 bytes per value, stored as little-endian.
- FLOAT - 4 bytes per value, stored as little-endian.
- DOUBLE - 8 bytes per value, stored as little-endian.
- BYTE_ARRAY - 4 byte length stored as little endian, followed by bytes.
- FIXED_LEN_BYTE_ARRAY - just the bytes are stored.
PLAIN_DICTIONARYDeprecated dictionary encoding.
The values in the dictionary are encoded using PLAIN encoding. Since it is deprecated, RLE_DICTIONARY encoding is used for a data page, and PLAIN encoding is used for dictionary page.
RLEGroup packed run length encoding.
Usable for definition/repetition levels encoding and boolean values.
BIT_PACKEDBit packed encoding.
This can only be used if the data has a known max width. Usable for definition/repetition levels encoding.
DELTA_BINARY_PACKEDDelta encoding for integers, either INT32 or INT64.
Works best on sorted data.
DELTA_LENGTH_BYTE_ARRAYEncoding for byte arrays to separate the length values and the data.
The lengths are encoded using DELTA_BINARY_PACKED encoding.
DELTA_BYTE_ARRAYIncremental encoding for byte arrays.
Prefix lengths are encoded using DELTA_BINARY_PACKED encoding. Suffixes are stored using DELTA_LENGTH_BYTE_ARRAY encoding.
RLE_DICTIONARYDictionary encoding.
The ids are encoded using the RLE encoding.