Enum parquet::basic::LogicalType [−][src]
pub enum LogicalType {
NONE,
UTF8,
MAP,
MAP_KEY_VALUE,
LIST,
ENUM,
DECIMAL,
DATE,
TIME_MILLIS,
TIME_MICROS,
TIMESTAMP_MILLIS,
TIMESTAMP_MICROS,
UINT_8,
UINT_16,
UINT_32,
UINT_64,
INT_8,
INT_16,
INT_32,
INT_64,
JSON,
BSON,
INTERVAL,
}Common types (logical types) used by frameworks when using Parquet. This helps map between types in those frameworks to the base types in Parquet. This is only metadata and not needed to read or write the data.
Variants
NONEUTF8A BYTE_ARRAY actually contains UTF8 encoded chars.
MAPA map is converted as an optional field containing a repeated key/value pair.
MAP_KEY_VALUEA key/value pair is converted into a group of two fields.
LISTA list is converted into an optional field containing a repeated field for its values.
ENUMAn enum is converted into a binary field
DECIMALA decimal value. This may be used to annotate binary or fixed primitive types. The underlying byte array stores the unscaled value encoded as two's complement using big-endian byte order (the most significant byte is the zeroth element).
This must be accompanied by a (maximum) precision and a scale in the SchemaElement. The precision specifies the number of digits in the decimal and the scale stores the location of the decimal point. For example 1.23 would have precision 3 (3 total digits) and scale 2 (the decimal point is 2 digits over).
DATEA date stored as days since Unix epoch, encoded as the INT32 physical type.
TIME_MILLISThe total number of milliseconds since midnight. The value is stored as an INT32 physical type.
TIME_MICROSThe total number of microseconds since midnight. The value is stored as an INT64 physical type.
TIMESTAMP_MILLISDate and time recorded as milliseconds since the Unix epoch. Recorded as a physical type of INT64.
TIMESTAMP_MICROSDate and time recorded as microseconds since the Unix epoch. The value is stored as an INT64 physical type.
UINT_8An unsigned 8 bit integer value stored as INT32 physical type.
UINT_16An unsigned 16 bit integer value stored as INT32 physical type.
UINT_32An unsigned 32 bit integer value stored as INT32 physical type.
UINT_64An unsigned 64 bit integer value stored as INT64 physical type.
INT_8A signed 8 bit integer value stored as INT32 physical type.
INT_16A signed 16 bit integer value stored as INT32 physical type.
INT_32A signed 32 bit integer value stored as INT32 physical type.
INT_64A signed 64 bit integer value stored as INT64 physical type.
JSONA JSON document embedded within a single UTF8 column.
BSONA BSON document embedded within a single BINARY column.
INTERVALAn interval of time.
This type annotates data stored as a FIXED_LEN_BYTE_ARRAY of length 12. This data is composed of three separate little endian unsigned integers. Each stores a component of a duration of time. The first integer identifies the number of months associated with the duration, the second identifies the number of days associated with the duration and the third identifies the number of milliseconds associated with the provided duration. This duration of time is independent of any particular timezone or date.